@@ -3,8 +3,9 @@
 import logging
 logging.basicConfig()
 
-from FlaskSimpleAuth import Flask, jsonify as json, __version__ as VERSION
-app = Flask("demo")
+import FlaskSimpleAuth as fsa  # type: ignore
+json = fsa.jsonify
+app = fsa.Flask("demo")
 app.config.from_envvar("APP_CONFIG")
 
 # database initialisation
@@ -20,16 +21,19 @@ auth.init_app(app)
 # first, direct routes
 #
 
+
 # GET /version: show running FlaskSimpleAuth version
 @app.get("/version", authorize="ANY")
 def get_version():
-    return json(VERSION), 200
+    return json(fsa.__version__), 200
+
 
 # GET /now: give current time from database
 @app.get("/now", authorize="ANY")
 def get_now():
     return json(db.now()[0]), 200
 
+
 # GET /who: given authenticated user if available
 @app.get("/who", authorize="ANY")
 def get_who():
@@ -39,6 +43,7 @@ def get_who():
 # then register 3 blueprints
 #
 
+
 # stuff management by users
 from stuff import stuff
 app.register_blueprint(stuff)
